// generator/index.js
module.exports = (api, options, rootOptions) => {
  // 注入依赖
  api.extendPackage({
    dependencies: {
      rxjs: '^6.3.3',
      'vue-rx': '^6.1.0'
    }
  })

  if (options.addExample) {
    api.render('./template', {
      ...options
    })
  }
}

module.exports.hooks = (api) => {
  // api.entryFile 返回项目的主文件（main.js 或 main.ts)
  const mainPath = api.entryFile
  const rxLine = 'import VueRx from \'vue-rx\';'

  // 如果只是引入依赖可使用 injectImports API
  // injectImports 用于添加新的导入到主文件中
  // api.injectImports(mainPath, rxLine)

  // 在这里 需要引入依赖并使用use 这个钩子将在文件被写入硬盘之后被调用
  api.afterInvoke(() => {
    const { EOL } = require('os')
    const fs = require('fs')
    const contentMain = fs.readFileSync(api.resolve(mainPath), { encoding: 'utf-8' })
    const lines = contentMain.split(/\r?\n/g).reverse() // reverse之后 findIndex 就是找到最后一行的import了

    const lastImportIndex = lines.findIndex(line => line.match(/^import/)) // 找到最后一行import语句
    lines[lastImportIndex] += `${EOL}${rxLine}${EOL}${EOL}Vue.use(VueRx);` // 加入 use 语句

    fs.writeFileSync(mainPath, lines.reverse().join(EOL), { encoding: 'utf-8' })
  })
}
